#########################
Power System Optimization
#########################


This section contains examples of network optimization with PyPSA. PyPSA allows you to optimize networks with `Linopy <https://linopy.readthedocs.io>`_.


.. toctree::
    :maxdepth: 1

    ../examples/optimization-with-linopy.ipynb
    ../examples/capacity-constraint-per-bus.ipynb
    ../examples/multi-investment-optimisation.ipynb
    ../examples/chained-hydro-reservoirs.ipynb
    ../examples/generation-investment-screening-curve.ipynb
    ../examples/scigrid-lopf-then-pf.ipynb
    ../examples/scigrid-redispatch.ipynb
    ../examples/scigrid-sclopf.ipynb
    ../examples/simple-electricity-market-examples.ipynb
    ../examples/capacity-expansion-planning-single-node.ipynb
    ../examples/mga.ipynb
    ../examples/islanded-methanol-production.ipynb
    ../examples/transformer_example.ipynb
    ../examples/unit-commitment.ipynb
    ../examples/reserve-power.ipynb
    ../examples/optimization-with-linopy-migrate-extra-functionalities.ipynb
